

local InitializeSettings = function()
    local as = gSportsRNA
    local settingTable = as:GetTable("Settings")

    as:SetString(settingTable, "PlayerSkeleton", "data/sceneassets/rig/skeleton_player.rx3")
    as:SetString(settingTable, "PlayerSkeletonANT", "data/sceneassets/rig/skeleton_ant.rx3")

    -- Force LevelOfDetail - 'high', 'medium', 'low', 'superlow'
    local levelOfDetail = as:GetString(settingTable, "LevelOfDetail")
    if (levelOfDetail == "") then
        levelOfDetail = "high"
        as:SetString(settingTable, "LevelOfDetail", levelOfDetail)
    end

    -- Set up defaults (high detail)
    as:SetInt(settingTable, "DropMipRX3_MipsToDrop", 0)            -- number of mips to drop from RX3 textures
    as:SetInt(settingTable, "DropMipRX3_MinTexDimension", 6144)    -- minimum size (here we will ignore the number of mips to drop)
    as:SetInt(settingTable, "FlatShadow_ScaleReduction", 0)        -- flat shadow dimensions             (0 is normal, 1 is half, 2 is quarter, 3 is an eigth)
    as:SetInt(settingTable, "FlatShadow_MaxLights", 4)            -- max number of lights to allow
    as:SetFloat(settingTable, "FlatShadow_QuadLenMultiplier", 1.0)    -- multiplier for the length covered on ground by one quad; bigger means better performance, but lower quality
    as:SetInt(settingTable, "FlatShadow_Blur", 1)
    as:SetInt(settingTable, "TextureDetailLevel", 4)
    as:SetInt(settingTable, "SelfShadow", 1)
    as:SetInt(settingTable, "SelfShadow_ScaleReduction", 0)        -- selfshadow render scale reduction (0 normal, 1 half, 2 quartered)
    as:SetInt(settingTable, "PostFX_RainDrops", 1)
    if ( EA_PLATFORM_MAC == true ) then
        as:SetInt(settingTable, "PostFX_AutoExp", 0) -- Turn off autoexposure on MAC (This causes it to use simple exposure)
    else
        as:SetInt(settingTable, "PostFX_AutoExp", 1)
    end
    as:SetInt(settingTable, "PostFX_Bloom", 1)
    as:SetInt(settingTable, "PostFX_DOF", 1)
    as:SetInt(settingTable, "PostFX_Rectilinear", 1)
    as:SetInt(settingTable, "PostFX_Vignette", 1)
    as:SetInt(settingTable, "PostFX_Grain", 1)
    as:SetInt(settingTable, "PostFX_ColorCube", 1)
    as:SetInt(settingTable, "PostFX_ColorCubeDepth", 1)
    as:SetInt(settingTable, "PostFX_SSAO", 1)
    as:SetInt(settingTable, "PostFX_MotionBlur", 1)
    as:SetInt(settingTable, "TessellationQuality", 4) 
    as:SetInt(settingTable, "SubsurfaceScattering", 1)
    as:SetFloat(settingTable, "SubsurfaceScatteringIntensity", 1.5)
    -- LumBloom texture reduction (1 is normal, 1 is half, 2 is quarter, 3 is an eigth)
    as:SetInt(settingTable, "PostFX_LumBloom_ScaleReduction", 0)

    as:SetInt(settingTable, "Grass", 1)
    as:SetInt(settingTable, "Cloth", 1)
    as:SetInt(settingTable, "PitchSpray", 1)
    as:SetFloat(settingTable, "PlayerLodPercentageMultiplier", 1000000.0)
    as:SetInt(settingTable, "PlayerLodMinimum", 0)

    as:SetFloat(settingTable, "RainIntensityScaler", 1.0)
    as:SetFloat(settingTable, "Particle_HalfRes_ScaleReduction", 3) -- glares render target scale reduction (3 default)
    as:SetInt(settingTable, "MaxAnisotropy", -1) -- limit anisotropy level for textures

    -- Override..
       if (levelOfDetail == "medium") then

        as:SetInt(settingTable, "FlatShadow_ScaleReduction", 1)
        as:SetInt(settingTable, "FlatShadow_MaxLights", 4)
        as:SetInt(settingTable, "Grass", 1)
        as:SetInt(settingTable, "Cloth", 1)
        as:SetInt(settingTable, "PitchSpray", 1)
        as:SetInt(settingTable, "FlatShadow_Blur", 0)
        as:SetInt(settingTable, "SelfShadow_ScaleReduction", 1)
        as:SetFloat(settingTable, "PlayerLodPercentageMultiplier", 200.0)
        as:SetFloat(settingTable, "RainIntensityScaler", 0.5)
        as:SetInt(settingTable, "MaxAnisotropy", 2) -- limit anisotropy level
 	as:SetInt(settingTable, "PlayerLodMinimum", 0)

    elseif (levelOfDetail == "low" or levelOfDetail == "superlow") then
        -- Downsize Render to texture sizes and detail
        as:SetInt(settingTable, "DropMipRX3_MinTexDimension", 512)
        as:SetInt(settingTable, "DropMipRX3_MipsToDrop", 3)
        as:SetInt(settingTable, "FlatShadow_ScaleReduction", 1)
        as:SetInt(settingTable, "FlatShadow_MaxLights", 1)
        as:SetInt(settingTable, "FlatShadow_Blur", 1)
        as:SetInt(settingTable, "SelfShadow", 1)
        as:SetFloat(settingTable, "FlatShadow_QuadLenMultiplier", 1.5)
	as:SetInt(settingTable, "PlayerLodMinimum", 0)

        -- Disable grass and cloth
        as:SetInt(settingTable, "Grass", 1)
        -- cloth is enabled for hi lods
        -- in case of performance issues disable cloth and always use tucked jerseys
        as:SetInt(settingTable, "Cloth", 1)
        as:SetInt(settingTable, "PitchSpray", 1)

        -- disable pretty much all PostFX
        as:SetInt(settingTable, "PostFX_RainDrops", 1)
        --Need autoexpousre to make lighting correct
        --as:SetInt(settingTable, "PostFX_AutoExp", 1)
        as:SetInt(settingTable, "PostFX_Bloom", 1)
        as:SetInt(settingTable, "PostFX_DOF", 1)
        as:SetInt(settingTable, "PostFX_Rectilinear", 1)
        as:SetInt(settingTable, "PostFX_Vignette", 1)
        as:SetInt(settingTable, "PostFX_Grain", 1)
        as:SetInt(settingTable, "PostFX_ColorCube", 1)
        as:SetInt(settingTable, "PostFX_ColorCubeDepth", 1)
        as:SetInt(settingTable, "PostFX_MotionBlur", 1)

        as:SetFloat(settingTable, "PlayerLodPercentageMultiplier", 100000.0)
        as:SetFloat(settingTable, "RainIntensityScaler", 0.2)
        as:SetInt(settingTable, "MaxAnisotropy", 1) -- no anisotropy
    end

    if (levelOfDetail == "superlow") then
        -- any extra tweaks here..
    end
end
InitializeSettings()
InitializeSettings = nil
